.TH XWSCROLLBAR 3X
.SH NAME
XwscrollbarWidgetClass \- the X Widget's scrollbar widget
.SH SYNOPSIS
#include <X11/StringDefs.h>
.br
#include <X11/Intrinsic.h>
.br
#include <Xw/Xw.h>
.br
#include <Xw/Valuator.h>
.br
#include <Xw/Arrow.h>
.br
#include <Xw/ScrollBar.h>
.SH CLASSES
The ScrollBar is built from the Core, Composite, and
XwManager classes.
.PP
The widget class to use when creating a scrollbar is
XwscrollbarWidgetClass.  The class name for scrollbar is
ScrollBar.
.SH DESCRIPTION
The ScrollBar widget combines the Valuator and Arrow widgets
to implement a horizontal or vertical scrolling widget
containing a valuator and an arrow on each end of the
valuator.
.PP
As with the Valuator, input is supported through interactive
slider movement and selections on the slide area not
occupied by the slider.  Both types of input have a separate
callback list for communicating with the application.  The
arrows on each end of the valuator control additional input
to the valuator.  When an arrow is selected, the slider
within the valuator will be moved in the direction of the
arrow by an application supplied amount.  If the button is
held down, the slider will continue to move at a constant
rate.
.PP
The ScrollBar can be used by the application to attach to
objects scrolled under application control, or used by
composite widgets to implement predefined scrolled objects.
.SH "NEW RESOURCES"
The ScrollBar defines a set of resource types used by the
programmer to specify the data for the scrollbar.  The
programmer can also set the values for the Core, Composite
and Manager widget classes to set attributes for this
widget. To reference a resource in a .Xdefaults file, strip
off the XtN from the resource string.  The following table
contains the set of resources defined by ScrollBar.
.IP "" 16
ScrollBar Resource Set
Name              Class             Type   Default
__________________________________________________
XtNinitialDelay   XtCinitialDelay   int    500
XtNrepeatRate     XtCRepeatRate     int    100
XtNgranularity    XtCGranularity    int    2
.TP 5
XtNinitialDelay
.br
The ScrollBar supports smooth time sequenced movement
of the slider when a selection occurs on the arrows.
This resource defines the amount of delay to wait
between the initial selection and the slider starting
its repetitive movement.  The value is defined in
milliseconds.
.TP 5
XtNrepeatRate
.br
This resource defines the continuous repeat rate to use
to move the slider while the button is being held down
on an arrow.  The value is also defined in
milliseconds.
.TP 5
XtNgranularity
.br
This resource defines the increment in the valuator's
coordinate system to move the slider while continuous
scrolling.
.TP 0
.ti -5
INCORPORATED RESOURCES
.br
The ScrollBar creates itself by internally creating two
Arrow widgets and a Valuator.  As such, it uses a large
number of the resources defined by these widgets.  Many of
the attributes for these widgets can be set through the
\&.Xdefaults file or by use of XtSetValues() when
communicating with the ScrollBar.
.PP
It should be noted, that only the resources within the
following tables will have any effect on the valuator or
arrows.  The other resource types defined by the Valuator
and Arrow widgets are either overridden or unused by
ScrollBar.
.PP
The following tables list the resources incorporated by
ScrollBar.  For a complete description of these resources,
refer to the manual page listed in the table heading.
.IP "" 6
Primitive Resource Set \-\- XWPRIMITIVE(3X)
.ti -10
Name                Class               Type    Default
.br
.ti -10
______________________________________________________________
.br
.ti -10
XtNhighlightColor   XtCForeground       Pixel   Black
.br
.ti -4
.PP
XtNhighlightStyle   XtCHighlightStyle   int     pattern_border
.br
.ti -4
XtNhighlightTile    XtCHighlightTile    int     50_foreground
.br
.ti -4
XtNtraversalType    XtCTraversalType    int     highlight_off
.br
.IP "" 7
Valuator Resource Set \-\- XWVALUATOR(3X)
.ti -11
Name                  Class                 Type      Default
.br
.ti -11
______________________________________________________________
.br
.ti -11
XtNsliderMin          XtCSliderMin          int       0
.br
.ti -11
XtNsliderMax          XtCSliderMax          int       100
.br
.ti -11
XtNsliderExtent       XtCSliderExtent       int       10
.br
.ti -11
XtNsliderOrigin       XtCSliderOrigin       int       0
.br
.ti -11
XtNslideOrientation   XtCSlideOrientation   int       vertical
.br
.ti -11
XtNsliderMoved        XtCCallback           Pointer   NULL
.br
.ti -11
XtNsliderReleased     XtCCallback           Pointer   NULL
.br
.ti -11
XtNareaSelected       XtCCallback           Pointer   NULL
.br
.SH "INHERITED RESOURCES"
The following resources are inherited from the named
superclasses:
.IP "" 17
Core Resource Set \-\- CORE(3X)
.ti -22
Name                   Class                  Type             Default
.br
.ti -22
__________________________________________________________________________
.br
.ti -22
XtNancestorSensitive   XtCSenstitive          Boolean          TRUE
.br
.ti -22
XtNx                   XtCPosition            int              0
.br
.ti -22
XtNy                   XtCPosition            int              0
.br
.ti -22
XtNwidth               XtCWidth               int              0
.br
.ti -22
XtNheight              XtCHeight              int              0
.br
.ti -22
XtNdepth               XtCDepth               int              0
.br
.ti -22
XtNbackground          XtCBackground          Pixel            White
.br
.ti -22
XtNbackgroundPixmap    XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNborderWidth         XtCBorderWidth         int              1
.br
.ti -22
XtNborderColor         XtCBorderColor         Pixel            Black
.br
.ti -22
XtNborderPixmap        XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNsensitive           XtCSensitive           Boolean          TRUE
.br
.ti -22
XtNmappedWhenManaged   XtCMappedWhenManaged   Boolean          TRUE
.br
.ti -22
XtNdestroyCallback     XtCCallback            Pointer          NULL
.br
.ti -22
XtNtranslations        XtCTranslations        XtTranslations   NULL
.br
.IP "" 10
Manager Resource Set \-\- XWMANAGER(3X)
.ti -15
Name                    Class                   Type      Default
.br
.ti -15
____________________________________________________________________
.br
.ti -5
.PP
XtNforeground           XtCForeground           Pixel     Black
.br
.ti -5
XtNbackgroundTile       XtCBackgroundTile       int       background
.br
.ti -5
XtNhighlightThickness   XtCHighlightThickness   int       0
.br
.ti -5
XtNtraversalOn          XtCTraversalOn          Boolean   FALSE
.br
.ti -5
XtNlayout               XtCLayout               int       minimize
.br
.ti -5
XtNnextTop              XtCCallback             Pointer   NULL
.br
.SH "KEYBOARD TRAVERSAL"
If the XtNtraversalOn resource is set to True at either
create time or during a call to XtSetValues, the XwManager
superclass will automatically augment the manager widget's
translations to support keyboard traversal.  Refer to the
XwManager man page for a complete description of these
translations.
.SH ORIGIN
Hewlett-Packard Company.
.SH "SEE ALSO"
CORE(3X), XWMANAGER(3X), XWPRIMITIVE(3X), XWCREATETILE(3X),
XWVALUATOR(3X), XWARROW(3X),
.br
Programming With The HP X Widgets,
.br
Programming With Xt Intrinsics,
.br
Programming With Xlib.
